<?php

/**
 * backup.php
 * ----------
 * @version 5.4.0
 * @copyright 2002-2010 Melbis Company
 * @link http://www.melbis.com
 * @author Dmitriy Kasyanov
 **/

// Define script folder 
define('FOLDER', './../');
 
// Require classes and includes
require_once('./privat/privat.php');
require_once('./includes/common.php');
require_once('./includes/admin.php');
require_once('./class/show/class.XML.php');
require_once('./class/util/class.PclZip.php');


// Set time limit 
@set_time_limit(3000); 

// Start session
session_start();

// What you need?
switch ($_POST['command'])
{
	case 'GET_TABLES_INFO' : 
		get_tables_info(); 
		break;
	case 'GET_TABLE_DATA' : 
		get_table_data(); 
		break;
	case 'PUT_TABLE_DATA' : 
		put_table_data(); 
		break;
	case 'LOCK_SHOP' : 
		lock_shop(); 
		break;		
	case 'UNLOCK_SHOP' : 
		unlock_shop(); 
		break;		
	default : 
		echo "PHP_ERROR: Unknow command in line [".__LINE__."] :: Fail Command";
}



/**
 * Function lock_shop
 * make shop temporary unavailable
 **/
function lock_shop()
{
	global $gData;
	
	// Connect to Data
	$gData = data_connect(true, array(), true);	
	
	// Lock
	$gData->SaveShopValue('main_available', 'False');
	
	sleep(0);
	
	echo "QUERY_EXECUTE";
}

/**
 * Function unlock_shop
 * make shop available and do other tasks
 **/
function unlock_shop()
{
	global $gData;
	
	
	// Connect to Data
	$gData = data_connect(true, array(), true);	
	
	// Unlock
	$gData->SaveShopValue('main_available', 'True');
	
	echo "QUERY_EXECUTE";
}

/**
 * Function get_tables_info
 * Get size data info of the tables
 **/
function get_tables_info()
{
	global $gData;
	
	// Connect to Data
	$gData = data_connect(true, array(), true);	
	
	// Start XML file
	$xml_file = './tmp/'.md5(session_id()).'.xml';
	$xml = new XML(SHOP_CHARSET, $xml_file);
	$xml->StartTag('MELBISSHOP', array('Version' => 'Melbis Shop v'.SCRIPT_VERSION));	
	
	// Request tables
	$info = $gData->GetTableStatus();
	$rows = $gData->GetNumRows($info);
	$xml->StartTag('TABLES', array('total' => $rows, 'transfer' => $rows));
	for ( $i = 1; $i <= $rows; $i++ ) 
	{	
		$hash = $gData->FetchHash($info);
		if ( substr($hash['Name'], 0, strlen(DB_NICK.'_')) != DB_NICK.'_' ) continue;
		$hash['Name'] = substr($hash['Name'], strlen(DB_NICK.'_'));
		$xml->PutTag('TABLE', $hash);
	}
	$xml->CloseTag('TABLES');
	$xml->CloseTag('MELBISSHOP');
	$xml->Free();
	
	// Put result to archive
	xml_to_zip_answer($xml_file);
}


/**
 * Function get_table_data
 * Get specificate table data
 **/
function get_table_data()
{
	global $gData;
	
	// Connect to Data
	$gData = data_connect(true, array(), true);	
	
	// Start XML file
	$xml_file = './tmp/'.md5(session_id()).'.xml';
	$xml = new XML(SHOP_CHARSET, $xml_file);
	$xml->StartTag('MELBISSHOP', array('Version' => 'Melbis Shop v'.SCRIPT_VERSION));	
	
	// Request data
	list ($table, $field_list, $start_field, $how_field) = explode(';', $_POST['values']);
	$info = $gData->GetTableValues($table, $field_list, '', false, ($start_field-1).', '.$how_field);
	$rows = $gData->GetNumRows($info);
	$xml->StartTag('PART', array('start' => $start_field, 'how' => $how_field));
	for ( $i = 1; $i <= $rows; $i++ ) 
	{	
		$xml->PutTag('ROW',  $gData->FetchHash($info));
	}
	$xml->CloseTag('PART');
	$xml->CloseTag('MELBISSHOP');
	$xml->Free();
	
	// Put result to archive
	xml_to_zip_answer($xml_file);
}

/**
 * Function put_table_data
 * Put specificate table data
 **/
function put_table_data()
{
	global $gData, $gTable, $gKeyField, $gUpdateField;
	
	// Connect to Data
	$gData = data_connect(true, array(), true);	

	if ( !file_exists($_FILES['string_file']['tmp_name']) ) die("PHP_ERROR: Don't received data file");

  	$Archive = new PclZip($_FILES['string_file']['tmp_name']);
  	if ( $Archive->extract('./tmp') <= 0 ) die("PHP_ERROR: Archive unpack error");	
	
  	// Table info
  	list ($gTable, $gKeyField, $gUpdateField, $start, $how) = explode(';', $_POST['values']);
  	$gKeyField = ( $gKeyField == '' ) ? array() : explode(',', $gKeyField);
  	$gUpdateField = ( $gUpdateField == '*' ) ? array() : explode(',', $gUpdateField);
  	
  	// Clear Table if need
	if ( $start == 1 && count($gUpdateField) == 0 )
	{
		$gData->ClearTable($gTable);
	}  	
  	
	// Parsing xml
	$xml_parser = xml_parser_create('UTF-8');
	xml_set_element_handler($xml_parser, "start_xml_tag", "end_xml_tag");
	xml_parser_set_option($xml_parser, XML_OPTION_CASE_FOLDING, FALSE);
	$data_file = './tmp/SomeData.xml';
	if ( !($fp = fopen($data_file, "r")) ) 
	{
		die("PHP_ERROR: Could not open Data.xml");
	}
	while ( $data = fread($fp, filesize($data_file)) ) 
	{
   		if ( !xml_parse($xml_parser, $data, feof($fp)) ) 
		{
       		die(sprintf("PHP_ERROR: XML parsing error: %s at line %d",
                   		xml_error_string(xml_get_error_code($xml_parser)),
                   		xml_get_current_line_number($xml_parser)));
		}
	}
	fclose($fp);
	xml_parser_free($xml_parser); 
	@unlink($data_file);
	
	echo "QUERY_EXECUTE";
}

/**
 * Function start_xml_tag
 **/
function start_xml_tag($mParser, $mName, $mAttrs) 
{
	global $gFields;

   	if ( $mName == 'ROW' ) 
	{ 
   		$gFields = array();
   		$gFields = $mAttrs;
	} 
	else 
	{
   		$gFields = array();
	}
}

/**
 * Function end_xml_tag
 **/
function end_xml_tag($mParser, $mName) 
{
  	global $gData, $gFields, $gTable, $gKeyField, $gUpdateField;
    
   	if ($mName == 'ROW') 
   	{
	  	// Do operation 
   		$gData->RestoreTableData($gFields, $gTable, $gKeyField, $gUpdateField);
   	}
}


?>