<?php

/**
 * class.XML.php
 * -------------
 * @version 5.4.0
 * @copyright 2002-2010 Melbis Company
 * @link http://www.melbis.com
 * @author Dmitriy Kasyanov
 **/
 
/** 
 * Class XML
 * Parse data to XML-file
 **/
class XML
{

	/**
	 * Vars 
	 **/
	var $gFile;
	var $gCharset;
	var $gXMLCharset;
	var $gTabs;
	var $gPocket;
	var $gToPocket;
	var $gBadChar = array();
	
	/**
     * Constructor
     */
	function XML($mCharset, $mFile, $mXMLCharset = 'UTF-8', $mStandAlone = true, $mPutTitle = true)
	{
		$this->gBadChar = array(chr(0), chr(8), chr(5) );
		$this->gCharset = $mCharset;
	    $this->gXMLCharset = $mXMLCharset;
		$this->gPocket = '';
		$this->gToPocket = FALSE;
		$this->gFile = fopen($mFile, "w");
		$this->gTabs = 0;
		if ( !iconv($this->gCharset, "UTF-8", 'Test charset') ) $this->gCharset = 'ISO-8859-1';
		$stand_alone = ( $mStandAlone ) ? 'standalone="yes"' : '';
		if ( $mPutTitle ) $code = '<?'.'xml version="1.0" encoding="'.$this->gXMLCharset.'" '.$stand_alone.' ?'.'>'."\r\n";
		fwrite($this->gFile, $code, strlen($code));
	}
	
	/**
     * Normalize
     */
	function Normalize($mTestMemo)
	{
		foreach ( $this->gBadChar as $char )
		{
			$mTestMemo = str_replace($char, '', $mTestMemo);
		}
		
		return $mTestMemo;
	}
	
	/**
	 * Start Tag
	 **/
	function StartTag($mNodeName, $mAttr = array())
	{
		$this->gTabs++;
		for($i = 0; $i < $this->gTabs; $i++)
		{
			$code .= ' ';
		}
		
		$code .= '<'.$mNodeName;
		if ( count($mAttr) > 0 ) 
		{
			foreach ($mAttr as $key => $value)
			{
				$code .= ' '.$key.'="'.iconv($this->gCharset, $this->gXMLCharset, htmlspecialchars($this->Normalize($value))).'"';
			}
		}
		$code .= '>'."\r\n";
		$this->gToPocket ? $this->gPocket .= $code : fwrite($this->gFile, $code, strlen($code));
	}
	
	/**
	 * Put Tag
	 **/
	function PutTag($mNodeName, $mAttr = array(), $mNodeValue = '', $mPut = true)
	{
		$code = '';
		$this->gTabs++;
		for($i = 0; $i < $this->gTabs; $i++)
		{
			$code .= ' ';
		}
		
		$code .= '<'.$mNodeName;
		if ( count($mAttr) > 0 ) 
		{
			foreach ($mAttr as $key => $value)
			{
				$code .= ' '.$key.'="'.iconv($this->gCharset, $this->gXMLCharset, htmlspecialchars($this->Normalize($value))).'"';
			}
		}
		if ( strlen($mNodeValue) > 0 ) 
		{
			$code .= '>';
			$code .= iconv($this->gCharset, $this->gXMLCharset, htmlspecialchars($mNodeValue));
			$code .= '</'.$mNodeName.'>'."\r\n";
			$this->gTabs--;
		}
		else
		{
			$code .= '/>'."\r\n";
			$this->gTabs--;
		}
		if ( $mPut ) 
		{
			$this->gToPocket ? $this->gPocket .= $code : fwrite($this->gFile, $code, strlen($code));
		}
		else
		{
			return $code;
		}
	}
	
	/**
	 * Put XML
	 **/
	function PutXML($mCode)
	{
		$this->gToPocket ? $this->gPocket .= $mCode : fwrite($this->gFile, $mCode, strlen($mCode));
	}
		
	/**
	 * CloseTag
	 **/
	function CloseTag($mNodeName)
	{
		$code = '';
		for($i = 0; $i < $this->gTabs; $i++) 
		{ 
			$code .= ' '; 
		}
		$this->gTabs--;
		$code .= '</'.$mNodeName.'>'."\r\n";
		$this->gToPocket ? $this->gPocket .= $code : fwrite($this->gFile, $code, strlen($code));
	}
	
	/**
	 * StartPocket
	 **/
	function StartPocket()
	{
		$this->gToPocket = TRUE;
		$this->gPocket = '';
	}
	
	/**
	 * ClosePocket
	 **/
	function ClosePocket()
	{
		$this->gToPocket = FALSE;
	}

	/**
	 * PrintPocket
	 **/
	function PrintPocket()
	{
		fwrite($this->gFile, $this->gPocket, strlen($this->gPocket));
	}
	
	/**
	 * Free
	 **/
	function Free()
	{
		fclose($this->gFile);
	}	
}


?>