<?php

/**
 * orders.php
 * ----------
 * @version 5.4.0
 * @copyright 2002-2010 Melbis Company
 * @link http://www.melbis.com
 * @author Dmitriy Kasyanov
 **/
 


/**
 * Function setup_orders_archive
 * Update orders from archive set status and payment
 **/
function setup_orders_archive($mStatus, $mPayment, $mSendEmail = array(), $mSendNote = array())
{
	global $gData, $gOptions, $gMessage, $gManager;
	
	// Set orders status
	foreach ( $mStatus as $order_id => $status_id ) 
	{	
		// Get order info
		$order_id *= 1;
		$order = $gData->GetArchiveOrder($order_id);
		if ( $order['id']*1 > 0 )
		{
			if ( $order['status'] == $status_id && $status_id == 0 ) continue;
	
			if ( ITS_MANAGER === true )
			{
				if ( $order['manager_id'] != $gManager['id'] && $order['manager_id'] > 0 ) continue;
				$gData->SetOrderManager($order_id, $gManager['id'] , get_now());		
			}
			
			// Update Status
			if ( $status_id != 5) 
			{
				$gData->UpdateArchiveStatus($order_id, $status_id, get_now());
				
				// Order is done
				if ( $status_id == 3 ) 
				{
					$gData->AddClientOrderSum($order['client_id'], $order['itogo_sum'] - $order['disc_sum']);		
					if ( $order['partner_id'] > 0 && $order['partner_sum'] > 0 )
					{
						$partner = $gData->GetPartner($order['partner_id']);
						$notice = sprintf($gMessage['part_pay_order'], 
										  $order['code'], 
										  date($gOptions['main_fmt_date_time'], strtotime($order['date_time'])),
										  number_format($partner['mult_proc']*100, 0, "," ,"'")
										  );
						$gData->AddPartnerAccount($order['partner_id'], 
												  get_now(), 
												  0, 
												  round($order['partner_sum']*$partner['mult_proc'], 2),
												  addslashes($notice)
												  );
					}
				}

				// Send E-mail to client
				if ( $mSendEmail[$order_id] == 1 || !array_key_exists($order_id, $mSendEmail) )
				{
					$client = $gData->GetClient($order['client_id']);
					send_email_note('status', $status_id, $client['email'], $client['charset'], $order['code'], $order['sid'], $order_id, $mSendNote[$order_id]);
				}
				
				// Send E-mail to partner
				if ( $status_id == 3 && $order['partner_id'] > 0 && $order['partner_sum'] > 0 ) 
				{
					send_partner_email($order['partner_id'], $order['partner_sum'], $notice);
				}
			}
			else
			{
				$gData->RemoveArchiveOrder($order_id);
			}
		}
	}
	
	// Set orders payment status
	foreach ( $mPayment as $order_id => $payment_id ) 
	{	
		$order_id *= 1;
		$order = $gData->GetArchiveOrder($order_id);
		if ( $order['id']*1 > 0 )
		{		
			if ( $order['get_payment'] == $payment_id ) continue;
			
			if ( ITS_MANAGER === true )
			{
				if ( $order['manager_id'] != $gManager['id'] && $order['manager_id'] > 0 ) continue;
				$gData->SetOrderManager($order_id, $gManager['id'] , get_now());		
			}
						
			$gData->UpdateArchivePayment($order_id, $payment_id, get_now());
			
			// Send E-mail
			if ( $mSendEmail[$order_id] == 1 || !array_key_exists($order_id, $mSendEmail) )
			{
				$order = $gData->GetArchiveOrder($order_id);
				$client = $gData->GetClient($order['client_id']);
				send_email_note('payment', $payment_id, $client['email'], $client['charset'], $order['code'], $order['sid'], $order_id, $mSendNote[$order_id]);
			}
		}
	}

}


/**
 * Function send_partner_email
 * Send email notice to partner 
 **/
function send_partner_email($mPartnerID, $mSuma, $mNotice)
{
	global $gData, $gOptions;
	
	// Get Partner
	$partner = $gData->GetPartner($mPartnerID);	
	
	$tplm = new FastTemplate(SHOP_CWD.'/'.TEMPLATES);
	$tplm->DefineTemplate(array('mail_message'	=>	'_partner/account/mails/mail_operate0.htm'));
	$tplm->Assign(array('NAME'  	=>  htmlspecialchars($partner['name']),
				    	'ID'		=> 	$partner['id'],
				    	'CURR'		=>	htmlspecialchars($gOptions['main_base_curr']),
				    	'SUMA'		=>  number_format($mSuma, 2, "," ,"'"),
				    	'NOTICE'	=>  htmlspecialchars($mNotice),
						'CHARSET' 	=>	$partner['charset'],
						'BASEURL'	=>  rtrim($gOptions['attr_base_url'], '/'),
						'SHOPNAMES'	=>  $gOptions['attr_shop_name'],
			    		'SHOPNAME'	=>  htmlspecialchars($gOptions['attr_shop_name']),
				    	'SHOPURL'	=>  htmlspecialchars($gOptions['attr_shop_url']),
				    	'SHOPEMAIL'	=>  htmlspecialchars($gOptions['attr_shop_email']),
				    	'SHOPORG'	=>  htmlspecialchars($gOptions['attr_shop_org']),
				    	'SHOPPHONE'	=>  htmlspecialchars($gOptions['attr_shop_phone']),
			    		'SHOPICQ'	=>  htmlspecialchars($gOptions['attr_shop_icq'])
			   		    ));
	$tplm->Parse('MAIL', 'mail_message');
	$mailer = new Emailer(MAIL_SERVER);
	$mailer->SetCharset($partner['charset']);
	$mailer->SetTypeHTML();
	$all_message = iconv(SHOP_CHARSET, $partner['charset'], $tplm->Fetch('MAIL'));
	$subject = substr($all_message, strpos($all_message, 'Message_subject:')+16, strpos($all_message, 'Message_content:')-16);
	$message = substr($all_message, strpos($all_message, 'Message_content:')+16);		
	$mailer->AddMessage($message);
	$mailer->BuildMessage();
	$mailer->Send($partner['email'], $gOptions['attr_shop_email'], ltrim($subject, " "));	
	
}

/**
 * Function send_email_note
 * Return email notice to buyer if order change status
 **/
function send_email_note($mType, $mCode, $mEmail, $mCharset, $mOrderCode, $mSSID, $mOrderID, $mSendNote = '')
{
	global $gData, $gOptions;
	
	$template = '';
	if ( $mType == 'status' && $mCode == '1' ) $template = 'status_accept.htm';
	if ( $mType == 'status' && $mCode == '2' ) $template = 'status_delivery.htm';
	if ( $mType == 'status' && $mCode == '3' ) $template = 'status_ok.htm';
	if ( $mType == 'status' && $mCode == '4' ) $template = 'status_nil.htm';
	if ( $mType == 'payment' && $mCode == '1' ) $template = 'payment_no.htm';
	if ( $mType == 'payment' && $mCode == '2' ) $template = 'payment_yes.htm';
	
	$tplm = new FastTemplate(SHOP_CWD.'/'.TEMPLATES);
	$tplm->DefineTemplate(array('mail_message'	=>	'_order/mails/change_status/'.$template,
								'admin_note'	=>  '_order/mails/change_status/admin_note.htm'));
	$tplm->Assign(array('ORDERCODE'	=>  $mOrderCode,
				    	'SSID'   	=>  $mSSID,
				    	'ORDERID'	=> 	$mOrderID,
						'CHARSET' 	=>	$mCharset,
						'SHOPNAMES'	=>  $gOptions['attr_shop_name'],
						'BASEURL'	=> 	rtrim($gOptions['attr_base_url'].'/', '/'),
				    	'SHOPNAME'	=>  htmlspecialchars($gOptions['attr_shop_name']),
				    	'SHOPURL'	=>  htmlspecialchars($gOptions['attr_shop_url']),
				    	'SHOPEMAIL'	=>  htmlspecialchars($gOptions['attr_shop_email']),
				    	'SHOPORG'	=>  htmlspecialchars($gOptions['attr_shop_org']),
				    	'SHOPPHONE'	=>  htmlspecialchars($gOptions['attr_shop_phone']),
				    	'SHOPICQ'	=>  htmlspecialchars($gOptions['attr_shop_icq']),
				    	'ADMINNOTE'	=>  ''
				   ));
	if ( strlen($mSendNote) > 0 )
	{
		$tplm->Assign('SENDNOTE', $mSendNote);
		$tplm->Parse('ADMINNOTE', 'admin_note');
	}
	$tplm->Parse('MAIL', 'mail_message');
	$mailer = new Emailer(MAIL_SERVER);
	$mailer->SetCharset($mCharset);
	$mailer->SetTypeHTML();
	$all_message = iconv(SHOP_CHARSET, $mCharset, $tplm->Fetch('MAIL'));
	$subject = substr($all_message, strpos($all_message, 'Message_subject:')+16, strpos($all_message, 'Message_content:')-16);
	$message = substr($all_message, strpos($all_message, 'Message_content:')+16);		
	$mailer->AddMessage($message);
  	$mailer->BuildMessage();
	$mailer->Send($mEmail, $gOptions['attr_shop_email'], ltrim($subject, " "));	
	
}


/**
 * Function order_archive_insert
 * Insert new order to archive
 **/
function order_archive_insert($mOrder, $mGoods, $mFields)
{
	global $gData, $gOptions, $gMessage, $gCharset;

	
	// Partner testing
	if ( $mOrder['partner_id'] > 0 )
	{
		$partner = $gData->GetPartner($mOrder['partner_id']);
		if ( $partner['id'] == 0 )
			return array('id' 				=> $mOrder['id'], 
			             'result' 			=> 'ErrorPartner', 
						 'order_code' 		=> $mOrder['code'], 
						 'order_date_time' 	=> date($gOptions['main_fmt_date_time'], strtotime($mOrder['date_time'])));
	}
	
	// Manager testing
	if ( $mOrder['manager_id'] > 0 )
	{
		$manager = $gData->GetManager($mOrder['manager_id']);
		if ( $manager['id'] == 0 )
			return array('id' 				=> $mOrder['id'], 
			             'result' 			=> 'ErrorManager', 
						 'order_code' 		=> $mOrder['code'], 
						 'order_date_time' 	=> date($gOptions['main_fmt_date_time'], strtotime($mOrder['date_time'])));
			
	}
	
	// Goods how testing ===========================================================
	
	if ( $mOrder['error_ignore'] != 1 )
	{
		$how = count($mGoods);
		for ( $i = 0; $i <= $how-1; $i++ ) 
		{			
			$hash = $mGoods[$i];
		
			// Get Goods options
			$goods = $gData->GetGoods($hash['store_id']);
			if ( ($goods['id'] == 0) || ($goods['active'] == 0) ) 
			{
				return array('id' 				=> $mOrder['id'], 
			    	         'result' 			=> 'ErrorGoodsAbsent', 
			        	     'goods_name' 		=> $hash['name'],
							 'order_code' 		=> $mOrder['code'], 
						 	 'order_date_time' 	=> date($gOptions['main_fmt_date_time'], strtotime($mOrder['date_time'])));
			}				

			// Max goods testing
			$max_order = $gData->GetMaxOrderGoods($hash['store_id'], $hash['param_value_id']);
			if ( $hash['how'] > $max_order )
			{
				return array('id' 				=> $mOrder['id'], 
			    	         'result' 			=> 'ErrorGoodsHow', 
			        	     'goods_name' 		=> $hash['name'],
			            	 'goods_how'		=> $max_order,
						 	 'order_code' 		=> $mOrder['code'], 
						 	 'order_date_time' 	=> date($gOptions['main_fmt_date_time'], strtotime($mOrder['date_time'])));
			}	
		}
	}

	
	// Client Create =========================================================
	
	// Add new client or search exists
	if ( $mOrder['client_id'] > 0 )
	{
		// Search client
		$client = $gData->GetClient($mOrder['client_id']);
		if ( $client['id'] < 2 ) 
			return array('id' 				=> $mOrder['id'], 
			             'result' 			=> 'ErrorClient', 
						 'order_code' 		=> $mOrder['code'], 
						 'order_date_time' 	=> date($gOptions['main_fmt_date_time'], strtotime($mOrder['date_time'])));
		// if hasn't fields read default						 
		if ( count($mFields) == 0 )
		{
			$fields = $gData->GetClientData($client['id']);	
			$rows = $gData->GetNumRows($fields);
			$allow = array();
			for ( $n = 1; $n <= $rows; $n++ ) 
			{			
				$hash = $gData->FetchRow($fields);
				if ( (strlen($hash[8]) > 0) || ($allow[$hash[0]] == 1) ) 
				{
					$allow[$hash[4]] = 1;			
					$mFields[] = array('order_id' 	=> $order_id,
									   'field_id'	=> $hash[0],
									   'name'		=> $hash[1],
									   'tlevel'		=> $hash[3],
									   'absindex'	=> $hash[5]+3,
									   'isfolder'	=> $hash[7],
									   'value_text'	=> $hash[8]
									  );
				}
			}
		}
	} 
	else 
	{
		// Add new client
		srand((double)microtime()*1000000);
       	$time = explode( " ", microtime());
		$login = 'auto'.($gData->GetLastClientID()*1+1).substr((double)$time[0],2,3);
		$password = substr(md5(rand(0,9999999)),1 ,8);
		$id = $gData->AddClient($login, $password, addslashes($mOrder['client_email']), get_date(), addslashes($gCharset[0]));
		$client = $gData->GetClient($id);
		$mOrder['client_id'] = $id;

		// Insert client fields as defult values
		$how = count($mFields);
		for ( $i = 0; $i <= $how-1; $i++ ) 
		{			
			$hash = $mFields[$i];
			if ( $hash['field_id'] > 0 ) 
			{
				$gData->AddClientField($client['id'], $hash['field_id'], addslashes($hash['value_text']));
			}
		}		
		
		// Send email
		if ( strlen($client['email']) > 0 )
		{
			$tplm = new FastTemplate(SHOP_CWD.'/'.TEMPLATES);
			$tplm->DefineTemplate(array('mail_message'	=>	'_client/register/mail_register.htm'));
			$tplm->Assign(array('LOGIN'  	=>  htmlspecialchars($login),
						    	'PASS'   	=>  htmlspecialchars($password),
								'CHARSET' 	=>	$client['charset'],
								'SHOPNAMES'	=>  $gOptions['attr_shop_name'],
				    			'SHOPNAME'	=>  htmlspecialchars($gOptions['attr_shop_name']),
					    		'SHOPURL'	=>  htmlspecialchars($gOptions['attr_shop_url']),
					    		'SHOPEMAIL'	=>  htmlspecialchars($gOptions['attr_shop_email']),
					    		'SHOPORG'	=>  htmlspecialchars($gOptions['attr_shop_org']),
					    		'SHOPPHONE'	=>  htmlspecialchars($gOptions['attr_shop_phone']),
				    			'SHOPICQ'	=>  htmlspecialchars($gOptions['attr_shop_icq'])
				   		    	));
			$tplm->Parse('MAIL', 'mail_message');
			$mailer = new Emailer(MAIL_SERVER);
			$mailer->SetCharset($client['charset']);
			$mailer->SetTypeHTML();
			$all_message = iconv(SHOP_CHARSET, $client['charset'], $tplm->Fetch('MAIL'));
			$subject = substr($all_message, strpos($all_message, 'Message_subject:')+16, strpos($all_message, 'Message_content:')-16);
			$message = substr($all_message, strpos($all_message, 'Message_content:')+16);		
			$mailer->AddMessage($message);
			$mailer->BuildMessage();
  			$mailer->Send($client['email'], $gOptions['attr_shop_email'], ltrim($subject, " "));					   
		}
	}

	// Order Start =========================================================
	
	// Create new order
	$order_code = str_replace('{NUM}', $gData->MakeOrderCode(), $gOptions['order_code_templ']);
	$order_id = $gData->AddArchiveOrder(session_id(),
				 					    addslashes($order_code),
	 									$mOrder['client_id'],
	 									$mOrder['partner_id'],
	 									$mOrder['date_time'],
	 									$mOrder['manager_id']
	 									);
	// Save client last order
	$gData->SaveClientBaseField($client['id'], 'last_date', get_now());

	
	// Client Info =========================================================
	
	// Add special fileds
	$client_category = $gData->GetCategoryName($client['category_id']);									   
	$gData->SaveArchiveClientField($order_id, -3, $gMessage['login'], 0, 0, 1, addslashes($client['login']));
	$gData->SaveArchiveClientField($order_id, -2, $gMessage['email'], 0, 1, 1, addslashes($client['email']));		
	$gData->SaveArchiveClientField($order_id, -1, $gMessage['category'], 0, 2, 1, addslashes($client_category[1]));
	
	// Save client information
	$how = count($mFields);
	for ( $i = 0; $i <= $how-1; $i++ ) 
	{			
		$hash = $mFields[$i];
		if ( $hash['field_id'] > 0 ) 
		{
			$gData->SaveArchiveClientField($order_id,
										   $hash['field_id'], 
										   addslashes($hash['name']),
										   $hash['tlevel'],
										   $hash['absindex'],
										   $hash['isfolder'],
										   addslashes($hash['value_text'])
										   );
		}
	}
	
	
	// Goods info ===========================================================
	
	$how = count($mGoods);
	for ( $i = 0; $i <= $how-1; $i++ ) 
	{			
		$hash = $mGoods[$i];
			
		// Save to order info
		$gData->AddArchiveBasket($order_id,
								 $hash['store_id'],
								 addslashes($hash['code']),
								 addslashes($hash['meas']),
								 addslashes($hash['name']),
								 addslashes($hash['param_name']),
								 $hash['param_personal'],
								 $hash['param_value_id'],
								 $hash['price'],
								 $hash['new_price'],
								 $hash['status'],
								 $hash['how'],
								 $hash['part_proc'],
								 $hash['part_value'],
								 addslashes($hash['modify_code']),
								 $hash['provider_id'],
								 $hash['prov_price'],
								 $hash['tax'],
								 $hash['inside_disc']
								 );

		// Save shop statistic
		$gData->SaveStatGoodsBuy(get_date(), get_week(), get_month(), $hash['store_id'], $hash['new_price']);
	
	}
	
	// Order info ===========================================================	
					  
	// Save order params
	$gData->SaveArchiveOrder($order_id,
							 $mOrder['disc_sum'],
							 addslashes($mOrder['cond_name']),
							 $mOrder['cond_cost'],
							 addslashes($mOrder['deliv_name']),
							 $mOrder['deliv_cost'],
							 addslashes($mOrder['payment_name']),
							 $mOrder['payment_cost'],
							 addslashes($mOrder['payment_curr']),
							 $mOrder['payment_id'],
							 $mOrder['itogo_sum'],
							 $mOrder['total_sum'],
							 addslashes($mOrder['notice']),
							 $mOrder['partner_sum'],
							 $mOrder['deliv_id'],
							 addslashes($mOrder['cond_code'])
							 );

	//  Save order inside notice
	$gData->UpdateArchiveNotice($order_id, addslashes($mOrder['inside_note']), get_now());							 
							 
	// Save shop statistic
	save_shop_stat('order', 0, addslashes($order_code), $mOrder['total_sum']);
							

	// Send email to client
	if ( @eregi("^[_a-z0-9-]+(\.[_a-z0-9-]+)*@([0-9a-z](-?[0-9a-z])*\.)+[a-z]{2}([zmuvtg]|fo|me)?$", $client['email']) ) 
	{
		$payment = $gData->GetPaymentValue($mOrder['payment_id']);
		$rows = $gData->GetNumRows($payment);
		if ( $rows > 0 ) 
		{
			$hash = $gData->FetchRow($payment);	
			$payment_online = $hash[12];
		}
	
		$tplm = new FastTemplate(SHOP_CWD.'/'.TEMPLATES.'/_order/mails');
		$tplm->DefineTemplate(array('mail_message'	=>	'for_client.htm',
									'pay_online'	=>	'pay_online.htm',
									'wait_accept'	=> 	'wait_accept.htm'
									));
		if ( $payment_online )
		{
			$tplm->Parse('ADDINFO', 'pay_online');
		}
		else 
		{
			$tplm->Parse('ADDINFO', 'wait_accept');
		}									
		$tplm->Assign(array('ORDERCODE'	=> htmlspecialchars($order_code),
					    	'SSID'   	=> session_id(),
					    	'ORDERID'	=> $order_id,
							'CHARSET' 	=> $client['charset'],
							'BASEURL'	=> rtrim($gOptions['attr_base_url'], '/'),
							'SHOPNAMES'	=> $gOptions['attr_shop_name'],
					    	'SHOPNAME'	=> htmlspecialchars($gOptions['attr_shop_name']),
					    	'SHOPURL'	=> htmlspecialchars($gOptions['attr_shop_url']),
					    	'SHOPEMAIL'	=> htmlspecialchars($gOptions['attr_shop_email']),
					    	'SHOPORG'	=> htmlspecialchars($gOptions['attr_shop_org']),
					    	'SHOPPHONE'	=> htmlspecialchars($gOptions['attr_shop_phone']),
					    	'SHOPICQ'	=> htmlspecialchars($gOptions['attr_shop_icq'])
					   ));
		$tplm->Parse('MAIL', 'mail_message');
		$mailer = new Emailer(MAIL_SERVER);
		$mailer->SetCharset($client['charset']);
		$mailer->SetTypeHTML();
		$all_message = iconv(SHOP_CHARSET, $client['charset'], $tplm->Fetch('MAIL'));
		$subject = substr($all_message, strpos($all_message, 'Message_subject:')+16, strpos($all_message, 'Message_content:')-16);
		$message = substr($all_message, strpos($all_message, 'Message_content:')+16);		
		$mailer->AddMessage($message);
  		$mailer->BuildMessage();
	  	$mailer->Send($client['email'], $gOptions['attr_shop_email'], ltrim($subject, " "));
	}	
	
	// Setup another status for order
	if ( $mOrder['status'] > 0 || $mOrder['get_payment'] > 1 )
	{
		setup_orders_archive(array($order_id => $mOrder['status']), 
							 array($order_id => $mOrder['get_payment']), 
							 array($order_id => $mOrder['send_email']), 
							 array($order_id => $mOrder['send_note'])
							 );
	}
	
	
	return array('id' => $mOrder['id'], 'result' => 'AddOK', 'order_id' => $order_id, 'order_code' => $order_code);
}	


/**
 * Function order_archive_update
 * Update info order to archive
 **/
function order_archive_update($mOrder, $mGoods, $mFields)
{
	global $gData, $gOptions, $gMessage, $gCharset;
	
	// Partner testing
	if ( $mOrder['partner_id'] > 0 )
	{
		$partner = $gData->GetPartner($mOrder['partner_id']);
		if ( $partner['id'] == 0 )
			return array('id' 				=> $mOrder['id'], 
			             'result' 			=> 'ErrorPartner', 
						 'order_code' 		=> $mOrder['code'], 
						 'order_date_time' 	=> date($gOptions['main_fmt_date_time'], strtotime($mOrder['date_time'])));
	}
	
	// Manager testing
	if ( $mOrder['manager_id'] > 0 )
	{
		$manager = $gData->GetManager($mOrder['manager_id']);
		if ( $manager['id'] == 0 )
			return array('id' 				=> $mOrder['id'], 
			             'result' 			=> 'ErrorManager', 
						 'order_code' 		=> $mOrder['code'], 
						 'order_date_time' 	=> date($gOptions['main_fmt_date_time'], strtotime($mOrder['date_time'])));
			
	}
	
	// Client testing
	$client = $gData->GetClient($mOrder['client_id']);
	if ( $client['id'] < 2 ) 
	{
		return array('id' 				=> $mOrder['id'], 
		             'result' 			=> 'ErrorClient', 
					 'order_code' 		=> $mOrder['code'], 
					 'order_date_time' 	=> date($gOptions['main_fmt_date_time'], strtotime($mOrder['date_time'])));
	}

	// Order testing
	$order_id = $mOrder['order_id'];
	$order = $gData->GetArchiveOrder($order_id);
	if ( $order['id'] == 0 ) 
	{
		return array('id' 				=> $mOrder['id'], 
		             'result' 			=> 'ErrorOrder', 
					 'order_code' 		=> $mOrder['code'], 
					 'order_date_time' 	=> date($gOptions['main_fmt_date_time'], strtotime($mOrder['date_time'])));
	}
	
	// Goods how testing ====================================================================
	
	if ( $mOrder['error_ignore'] != 1 )
	{
		$how = count($mGoods);
		for ( $i = 0; $i <= $how-1; $i++ ) 
		{
			$hash = $mGoods[$i];
		
			// Get Goods options
			$goods = $gData->GetGoods($hash['store_id']);
			if ( ($goods['id'] == 0) || ($goods['active'] == 0) ) 
			{
				return array('id' 				=> $mOrder['id'], 
			    	         'result' 			=> 'ErrorGoodsAbsent', 
			        	     'goods_name' 		=> $hash['name'],
							 'order_code' 		=> $mOrder['code'], 
						 	 'order_date_time' 	=> date($gOptions['main_fmt_date_time'], strtotime($mOrder['date_time'])));
			}

			// Max goods testing
			$max_order = $gData->GetMaxOrderGoods($hash['store_id'], $hash['param_value_id']);
			if ( $hash['how'] > $max_order )
			{
				return array('id' 				=> $mOrder['id'], 
			    	         'result' 			=> 'ErrorGoodsHow', 
			        	     'goods_name' 		=> $hash['name'],
			            	 'goods_how'		=> $max_order,
						 	 'order_code' 		=> $mOrder['code'], 
						 	 'order_date_time' 	=> date($gOptions['main_fmt_date_time'], strtotime($mOrder['date_time'])));
			}
		}
	}

	// Order Start =========================================================
	
	// Create new order
	$update_time = $gData->UpdateArchiveOrder($order_id,
	 										  $mOrder['partner_id'],
	 						   				  $mOrder['manager_id'],
	 						   				  $mOrder['date_time'],
	 						   				  get_now()
	 						   				 );
	// Save client last order
	$gData->SaveClientBaseField($client['id'], 'last_date', get_now());

	
	// Client Info =========================================================
	
	// Add special fileds
	$client_category = $gData->GetCategoryName($client['category_id']);									   
	$gData->SaveArchiveClientField($order_id, -3, $gMessage['login'], 0, 0, 1, addslashes($client['login']));
	$gData->SaveArchiveClientField($order_id, -2, $gMessage['email'], 0, 1, 1, addslashes($client['email']));		
	$gData->SaveArchiveClientField($order_id, -1, $gMessage['category'], 0, 2, 1, addslashes($client_category[1]));
	
	// Save client information
	$how = count($mFields);
	for ( $i = 0; $i <= $how-1; $i++ ) 
	{			
		$hash = $mFields[$i];
		if ( $hash['field_id'] > 0 ) 
		{
			$gData->SaveArchiveClientField($order_id,
										   $hash['field_id'], 
										   addslashes($hash['name']),
										   $hash['tlevel'],
										   $hash['absindex'],
										   $hash['isfolder'],
										   addslashes($hash['value_text'])
										   );
		}
	}
	
	
	// Goods info ===========================================================
	
	$how = count($mGoods);
	for ( $i = 0; $i <= $how-1; $i++ ) 
	{			
		$hash = $mGoods[$i];
			
		// Save to order info
		$gData->AddArchiveBasket($order_id,
								 $hash['store_id'],
								 addslashes($hash['code']),
								 addslashes($hash['meas']),
								 addslashes($hash['name']),
								 addslashes($hash['param_name']),
								 $hash['param_personal'],
								 $hash['param_value_id'],
								 $hash['price'],
								 $hash['new_price'],
								 $hash['status'],
								 $hash['how'],
								 $hash['part_proc'],
								 $hash['part_value'],
								 addslashes($hash['modify_code']),
								 $hash['provider_id'],
								 $hash['prov_price'],
								 $hash['tax'],
								 $hash['inside_disc']
								 );
	}
	
	// Order info ===========================================================	
					  
	// Save order params
	$gData->SaveArchiveOrder($order_id,
							 $mOrder['disc_sum'],
							 addslashes($mOrder['cond_name']),
							 $mOrder['cond_cost'],
							 addslashes($mOrder['deliv_name']),
							 $mOrder['deliv_cost'],
							 addslashes($mOrder['payment_name']),
							 $mOrder['payment_cost'],
							 addslashes($mOrder['payment_curr']),
							 $mOrder['payment_id'],
							 $mOrder['itogo_sum'],
							 $mOrder['total_sum'],
							 addslashes($mOrder['notice']),
							 $mOrder['partner_sum'],
							 $mOrder['deliv_id'],
							 addslashes($mOrder['cond_code'])
							 );

	//  Save order inside notice
	$gData->UpdateArchiveNotice($order_id, addslashes($mOrder['inside_note']), get_now);							 
							 
	// Setup status for order
	setup_orders_archive(array($order_id => $mOrder['status']), 
						 array($order_id => $mOrder['get_payment']), 
						 array($order_id => $mOrder['send_email']), 
						 array($order_id => $mOrder['send_note'])
						 );
	
	return array('id' => $mOrder['id'], 'result' => 'EditOK', 'order_id' => $order_id, 'order_code' => $mOrder['code']);
}	



/**
 * Function get_order_xml
 * Return archive order in xml
 **/
function get_order_xml($mOrderID)
{
	global $gData;
	
	// Start XML file
	$xml_file = './tmp/'.md5(session_id()+'get_order_xml').'.xml';
	$xml = new XML(SHOP_CHARSET, $xml_file, 'UTF-8', true, false);
	
	// Parse order
	$order = $gData->GetArchiveOrder($mOrderID);
	$xml->StartTag('ORDER');
	$order['status_was'] = $order['status'];
	$order['payment_was'] = $order['get_payment'];
	$order['send_email'] = 'True';
	$xml->PutTag('ROW', $order);
	$xml->CloseTag('ORDER');
		
	// Parse order client
	$xml->StartTag('CLIENT');
	$client = $gData->GetArchiveClientField($mOrderID);
	$client_rows = $gData->GetNumRows($client);
	for ( $n = 1; $n <= $client_rows; $n++ ) 
	{	
		$hash = $gData->FetchHash($client);
		( $hash['isfolder'] != 1 ) ? $dot = ' ' : $dot = '';
		$hash['tab_name'] = str_repeat('    ', $hash['tlevel']).$dot.$hash['name'];			
		$xml->PutTag('ROW', $hash);
	}	
	$xml->CloseTag('CLIENT');
	
	// Parse order goods
	$xml->StartTag('GOODS');
	$goods = $gData->GetArchiveGoods($mOrderID);
	$goods_rows = $gData->GetNumRows($goods);
	for ( $n = 1; $n <= $goods_rows; $n++ ) 
	{	
		$hash = $gData->FetchHash($goods);
		$xml->PutTag('ROW', $hash);
	}
	$xml->CloseTag('GOODS');
	
	$xml->Free();

	$xml_code = implode('',@file($xml_file));
	@unlink($xml_file);

	return $xml_code;
}


//***************************************************************************************************
//
// 						   		Main functions
//
//***************************************************************************************************	


/**
 * Function save_order_note
 * Save order inside notice
 **/
function save_order_note()
{
	global $gData;
	
	$gData->UpdateArchiveNotice($_POST['values']*1, addslashes(zip_file_to_string($_FILES['string_file']['tmp_name'])), get_now());
	
	echo "QUERY_EXECUTE";
}


/**
 * Function update_orders_archive
 * Update orders from archive set status and payment
 **/
function update_orders_archive()
{
	global $gData, $gOptions;
	
	list($set_status, $set_payment, $set_send_note, $set_send_email) = explode(':', zip_file_to_string($_FILES['string_file']['tmp_name']));
	$status_line = explode(';', trim($set_status, ';'));
	$payment_line = explode(';', trim($set_payment, ';'));
	$send_note_line = explode(';', trim($set_send_note, ';'));
	$send_email_line = explode(';', trim($set_send_email, ';'));
	foreach ($status_line as $var) 
	{	
		list($key, $value) = explode('=', $var);
		$status[$key] = $value;
	}
	foreach ($payment_line as $var) 
	{	
		list($key, $value) = explode('=', $var);	
		$payment[$key] = $value;
	}
	foreach ($send_note_line as $var)
	{
		list($key, $value) = explode('=', $var);
		$send_note[$key] = urldecode($value);
	}	
	foreach ($send_email_line as $var)
	{
		list($key, $value) = explode('=', $var);
		$send_email[$key] = urldecode($value);
	}	
				
	
	// Update status orders
	setup_orders_archive($status, $payment, $send_email, $send_note);
	
	echo "QUERY_EXECUTE";
}


/**
 * Function compare_archive_orders
 * Return archive orders need to update
 **/
function compare_archive_orders()
{
	global $gData;
	
	list ($start_date_time, $end_date_time ) = explode(';', $_POST['values']);
	
	$vars = explode('&', zip_file_to_string($_FILES['string_file']['tmp_name']));
	foreach ($vars as $var)
	{
		list($key, $value) = explode('=', $var);
		$input[$key] = $value;
	}	
	unset($input[0]);
	
	
	// Start XML file
	$xml_file = './tmp/'.md5(session_id()).'.xml';
	$xml = new XML(SHOP_CHARSET, $xml_file);
	$xml->StartTag('MELBISSHOP');
	
	// Parse orders
	$OPS = 500;
	$xml->StartTag('ORDER');
	$orders = $gData->GetArchiveOrders('order_datetime', $_POST['values']);
	$order_rows = $gData->GetNumRows($orders);
	$how = 0;
	for ( $i = 1; $i <= $order_rows; $i++ )
	{
		if ( $how >= $OPS ) break;
		$order_hash = $gData->FetchHash($orders);
		if ( $input[$order_hash['id']] != $order_hash['update_time'] )
		{
			$order_hash['status_was'] = $order_hash['status'];
			$order_hash['payment_was'] = $order_hash['get_payment'];
			$order_hash['send_email'] = 'True';
			$xml->PutTag('ROW', $order_hash);
			$input[$order_hash['id']] = $order_hash['update_time'];
			$how++;
		}
		else 
		{
			unset($input[$order_hash['id']]);
		}
	}	
	$total = $how;
	for ( $i = $how + 1; $i <= $order_rows; $i++ )
	{
		$order_hash = $gData->FetchHash($orders);
		if ( $input[$order_hash['id']] != $order_hash['update_time'] )
		{
			$total++;
		}
		unset($input[$order_hash['id']]);
	}	
	$xml->CloseTag('ORDER');
	
	$ghost = array();
		
	// Parse order client
	$xml->StartTag('CLIENT');
	foreach ( $input as $id => $value )
	{	
		$client = $gData->GetArchiveClientField($id);
		$client_rows = $gData->GetNumRows($client);
		if ( $client_rows == 0 ) $ghost[$id] = 1;
		
		for ( $n = 1; $n <= $client_rows; $n++ ) 
		{	
			$hash = $gData->FetchHash($client);
			( $hash['isfolder'] != 1 ) ? $dot = ' ' : $dot = '';
			$hash['tab_name'] = str_repeat('    ', $hash['tlevel']).$dot.$hash['name'];			
			$xml->PutTag('ROW', $hash);
		}
	}	
	$xml->CloseTag('CLIENT');
	
	// Parse order goods
	$xml->StartTag('GOODS');
	foreach ( $input as $id => $value )
	{	
		$goods = $gData->GetArchiveGoods($id);
		$goods_rows = $gData->GetNumRows($goods);
		if ( $goods_rows == 0 ) $ghost[$id] = 1;
		
		for ( $n = 1; $n <= $goods_rows; $n++ ) 
		{	
			$hash = $gData->FetchHash($goods);
			$xml->PutTag('ROW', $hash);
		}
	}
	$xml->CloseTag('GOODS');
	
	// Orders for delete
	$xml->StartTag('GHOST');
	foreach ( $ghost as $id => $value)
	{	
		$xml->PutTag('ROW', array('id' => $id) );
	}	
	$xml->CloseTag('GHOST');		
	
	$xml->PutTag('INFO', array('total' => $total, 'transfer' => $how));	
	
	$xml->CloseTag('MELBISSHOP');
	$xml->Free();
	
	// Put result to archive
	xml_to_zip_answer($xml_file);	
}


/**
 * Function get_client_fields
 * Return client fields
 **/
function get_client_fields()
{
	global $gData, $gMessage;
	
	// Start XML file
	$xml_file = './tmp/'.md5(session_id()).'.xml';
	$xml = new XML(SHOP_CHARSET, $xml_file);
	$xml->StartTag('MELBISSHOP');
	
	$vars = explode('&', $_POST['values']);
	foreach ($vars as $var)
	{
		list($key, $value) = explode('=', $var);
		$input[$key] = urldecode($value);
	}
	
		
	// Parse orders
	$client = $gData->GetClient($input['client_id']*1);
	$fields = $gData->GetClientData($input['client_id']*1, '', '', true);
	$fields_rows = $gData->GetNumRows($fields);
	$xml->StartTag('FIELDS', array('total' => $fields_rows + 3));
	$hash = array();
	$hash['field_id'] = '-3';
	$hash['name'] = $gMessage['login'];
	$hash['tlevel'] = 0;
	$hash['absindex'] = 0;
	$hash['isfolder'] = 1;
	$hash['tab_name'] = $hash['name'];
	$hash['order_id'] = $input['order_id'];
	$hash['value_text'] = $client['login'];
	$xml->PutTag('FIELD', $hash);
	$hash = array();
	$hash['field_id'] = '-2';
	$hash['name'] = $gMessage['email'];
	$hash['tlevel'] = 0;
	$hash['absindex'] = 1;
	$hash['isfolder'] = 1;
	$hash['tab_name'] = $hash['name'];
	$hash['order_id'] = $input['order_id'];
	$hash['value_text'] = $client['email'];
	$xml->PutTag('FIELD', $hash);
	$hash = array();
	$hash['field_id'] = '-1';
	$hash['name'] = $gMessage['category'];
	$hash['tlevel'] = 0;
	$hash['absindex'] = 2;
	$hash['isfolder'] = 1;
	$hash['tab_name'] = $hash['name'];
	$hash['order_id'] = $input['order_id'];
	$xml->PutTag('FIELD', $hash);
	for ( $i = 1; $i <= $fields_rows; $i++ )
	{
		$hash = $gData->FetchHash($fields);
		$hash['field_id'] = $hash['id'];
		unset($hash['id']);
		unset($hash['descr']);
		unset($hash['tindex']);
		unset($hash['need']);
		( $hash['isfolder'] != 1 ) ? $dot = ' ' : $dot = '';
		$hash['tab_name'] = str_repeat('    ', $hash['tlevel']).$dot.$hash['name'];			
		$hash['order_id'] = $input['order_id'];
		$hash['absindex'] += 3;
		$xml->PutTag('FIELD', $hash);
	}
	$xml->CloseTag('FIELDS');

	$xml->CloseTag('MELBISSHOP');
	$xml->Free();
	
	// Put result to archive
	xml_to_zip_answer($xml_file);	
}





?>